@@ -1,8 +1,5 @@
 #!/usr/bin/perl -w
 
-# $Id$
-
 use strict;
 use Test::Harness;
-
-runtests(qw(bin/test_date-holidays_modules.t));
+runtests(qw(scripts/test_date-holidays_modules.t));
